import axios from 'axios';

interface ITutorialData {
  paymentId: number;
  paymentCode: string;
  paymentMethod: string;
}

type CUSTOMER = {
  first_name: string;
  last_name: string;
  email: string;
  phone: string;
  address: string;
};

type CARD_ITEM = {
  name: string;
  price: number;
  quantity: number;
};

interface IRequestData {
  payment_method_id: number;
  cartTotal: number;
  currency: string;
  customer: CUSTOMER;
  cartItems: Array<CARD_ITEM>;
}

const APIURL = 'https://staging.fawaterk.com/api/v2';

const instanceAPI = axios.create({
  baseURL: APIURL,
});

instanceAPI.interceptors.request.use(
  (config) => {
    if (config.method === 'post' && config.data === undefined) {
      config.data = {};
    }
    if (config.method === 'get') {
      // Add headers or any other specific logic for GET requests here
      config.headers['Custom-Header'] = 'Custom Value';
    }
    return config;
  },
  (error) => Promise.reject(error)
);

export const getPaymentTypes = async (TOKEN: string) => {
  const result = await instanceAPI.get<Array<ITutorialData>>(
    '/getPaymentmethods',
    {
      headers: {
        'Authorization': `Bearer ${TOKEN}`,
        'content-type': 'application/json',
      },
    }
  );
  return result.data;
};

export const createRequest = async (
  TOKEN: string,
  requestUrl: string,
  requestData: IRequestData
) => {
  return new Promise(async (resolve, reject) => {
    try {
      const result = await instanceAPI.post(requestUrl, requestData, {
        headers: {
          Authorization: `Bearer ${TOKEN}`,
        },
      });
      resolve(result.data);
    } catch (err) {
      reject({
        status: 'error',
        message: null,
      });
    }
  });
};
